summaryrefslogtreecommitdiffstats
path: root/apps
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:39:49 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:39:49 -0600
commitbb37c4052a9edfff2196984cef241b1ce2df7bb3 (patch)
tree20f184005dcb8d5315aec18cb3253c7ff452c8ca /apps
parenta90eb215f53c95d81f95b32255098066d90556d9 (diff)
downloadktorrent-bb37c4052a9edfff2196984cef241b1ce2df7bb3.tar.gz
ktorrent-bb37c4052a9edfff2196984cef241b1ce2df7bb3.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'apps')
-rw-r--r--apps/ktcachecheck/cachechecker.cpp4
-rw-r--r--apps/ktcachecheck/multicachechecker.cpp4
-rw-r--r--apps/ktcachecheck/singlecachechecker.cpp2
-rw-r--r--apps/ktorrent/groups/groupview.cpp4
-rw-r--r--apps/ktorrent/groups/torrentgroup.cpp2
-rw-r--r--apps/ktorrent/ipfilterwidget.cpp2
-rw-r--r--apps/ktorrent/ipfilterwidgetbase.ui2
-rw-r--r--apps/ktorrent/ktorrent.cpp10
-rw-r--r--apps/ktorrent/ktorrentcore.cpp20
-rw-r--r--apps/ktorrent/ktorrentview.cpp22
-rw-r--r--apps/ktorrent/ktorrentviewitem.cpp12
-rw-r--r--apps/ktorrent/leaktrace.cpp4
-rw-r--r--apps/ktorrent/main.cpp2
-rw-r--r--apps/ktorrent/newui/button.cpp10
-rw-r--r--apps/ktorrent/newui/ddockwindow.cpp8
-rw-r--r--apps/ktorrent/newui/dmainwindow.cpp2
-rw-r--r--apps/ktorrent/newui/dtabwidget.cpp4
-rw-r--r--apps/ktorrent/pref.cpp2
-rw-r--r--apps/ktorrent/queuedialog.cpp4
-rw-r--r--apps/ktorrent/scandialog.cpp4
-rw-r--r--apps/ktorrent/scandlgbase.ui4
-rw-r--r--apps/ktorrent/speedlimitsdlg.cpp2
-rw-r--r--apps/ktorrent/torrentcreatordlg.cpp6
-rw-r--r--apps/ktorrent/torrentcreatordlgbase.ui2
-rw-r--r--apps/ktorrent/trayicon.cpp52
25 files changed, 95 insertions, 95 deletions
diff --git a/apps/ktcachecheck/cachechecker.cpp b/apps/ktcachecheck/cachechecker.cpp
index f05fb18..c8371a7 100644
--- a/apps/ktcachecheck/cachechecker.cpp
+++ b/apps/ktcachecheck/cachechecker.cpp
@@ -44,7 +44,7 @@ namespace ktdebug
this->index_file = index_file;
File fptr;
if (!fptr.open(index_file,"rb"))
- throw Error(i18n("Cannot open index file %1 : %2").tqarg(index_file).tqarg(fptr.errorString()));
+ throw Error(i18n("Cannot open index file %1 : %2").arg(index_file).arg(fptr.errorString()));
if (fptr.seek(File::END,0) != 0)
{
@@ -73,7 +73,7 @@ namespace ktdebug
File fptr;
if (!fptr.open(index_file,"wb"))
- throw Error(i18n("Cannot open index file %1 : %2").tqarg(index_file).tqarg(fptr.errorString()));
+ throw Error(i18n("Cannot open index file %1 : %2").arg(index_file).arg(fptr.errorString()));
std::set<bt::Uint32>::iterator i;
// first remove failed chunks from downloaded
diff --git a/apps/ktcachecheck/multicachechecker.cpp b/apps/ktcachecheck/multicachechecker.cpp
index 3132e12..53e8fee 100644
--- a/apps/ktcachecheck/multicachechecker.cpp
+++ b/apps/ktcachecheck/multicachechecker.cpp
@@ -79,7 +79,7 @@ namespace ktdebug
// we can read the chunk from this file
File fptr;
if (!fptr.open(cache + tf.getPath(),"rb"))
- throw Error(TQString("Cannot open %1 : %2").tqarg(cache + tf.getPath()).tqarg(fptr.errorString()));
+ throw Error(TQString("Cannot open %1 : %2").arg(cache + tf.getPath()).arg(fptr.errorString()));
fptr.seek(File::BEGIN,curr_file_off);
fptr.read(buf + bytes_offset,to_read);
@@ -94,7 +94,7 @@ namespace ktdebug
// Out() << "Partially reading " << to_read << endl;
File fptr;
if (!fptr.open(cache + tf.getPath(),"rb"))
- throw Error(TQString("Cannot open %1 : %2").tqarg(cache + tf.getPath()).tqarg(fptr.errorString()));
+ throw Error(TQString("Cannot open %1 : %2").arg(cache + tf.getPath()).arg(fptr.errorString()));
fptr.seek(File::BEGIN,curr_file_off);
fptr.read(buf + bytes_offset,to_read);
diff --git a/apps/ktcachecheck/singlecachechecker.cpp b/apps/ktcachecheck/singlecachechecker.cpp
index c311db1..ab64fc3 100644
--- a/apps/ktcachecheck/singlecachechecker.cpp
+++ b/apps/ktcachecheck/singlecachechecker.cpp
@@ -48,7 +48,7 @@ namespace ktdebug
if (!fptr.open(cache,"rb"))
{
throw Error(TQString("Cannot open file : %1 : %2")
- .tqarg(cache).tqarg( fptr.errorString()));
+ .arg(cache).arg( fptr.errorString()));
}
Uint32 num_ok = 0,num_not_ok = 0,num_not_downloaded = 0,extra_ok = 0;
diff --git a/apps/ktorrent/groups/groupview.cpp b/apps/ktorrent/groups/groupview.cpp
index 11a6aa6..92b78c3 100644
--- a/apps/ktorrent/groups/groupview.cpp
+++ b/apps/ktorrent/groups/groupview.cpp
@@ -163,7 +163,7 @@ namespace kt
if (gman->find(name))
{
- KMessageBox::error(this,i18n("The group %1 already exists.").tqarg(name));
+ KMessageBox::error(this,i18n("The group %1 already exists.").arg(name));
return;
}
@@ -214,7 +214,7 @@ namespace kt
if (gman->find(name))
{
- KMessageBox::error(this,i18n("The group %1 already exists.").tqarg(name));
+ KMessageBox::error(this,i18n("The group %1 already exists.").arg(name));
}
else
{
diff --git a/apps/ktorrent/groups/torrentgroup.cpp b/apps/ktorrent/groups/torrentgroup.cpp
index 65fed38..d44b744 100644
--- a/apps/ktorrent/groups/torrentgroup.cpp
+++ b/apps/ktorrent/groups/torrentgroup.cpp
@@ -51,7 +51,7 @@ namespace kt
if (hashes.count(tor->getInfoHash()))
{
/* bt::Out(SYS_GEN|LOG_DEBUG) <<
- TQString("TG %1 : Torrent %2 from hashes list").tqarg(groupName()).tqarg(tor->getStats().torrent_name) << endl;
+ TQString("TG %1 : Torrent %2 from hashes list").arg(groupName()).arg(tor->getStats().torrent_name) << endl;
*/
hashes.erase(tor->getInfoHash());
torrents.insert(tor);
diff --git a/apps/ktorrent/ipfilterwidget.cpp b/apps/ktorrent/ipfilterwidget.cpp
index 76ba43f..152e8c1 100644
--- a/apps/ktorrent/ipfilterwidget.cpp
+++ b/apps/ktorrent/ipfilterwidget.cpp
@@ -140,7 +140,7 @@ void IPFilterWidget::saveFilter(TQString& fn)
if (!fptr.open(IO_WriteOnly))
{
- Out(SYS_GEN|LOG_NOTICE) << TQString("Could not open file %1 for writing.").tqarg(fn) << endl;
+ Out(SYS_GEN|LOG_NOTICE) << TQString("Could not open file %1 for writing.").arg(fn) << endl;
return;
}
diff --git a/apps/ktorrent/ipfilterwidgetbase.ui b/apps/ktorrent/ipfilterwidgetbase.ui
index dea4bc2..e29ffe7 100644
--- a/apps/ktorrent/ipfilterwidgetbase.ui
+++ b/apps/ktorrent/ipfilterwidgetbase.ui
@@ -29,7 +29,7 @@
<property name="text">
<string>Note: Blacklist applies to current session only. Use save/open to save your entries or use IPFilter plugin (PeerGuardian).</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignVCenter</set>
</property>
</widget>
diff --git a/apps/ktorrent/ktorrent.cpp b/apps/ktorrent/ktorrent.cpp
index 85cb4f0..a113576 100644
--- a/apps/ktorrent/ktorrent.cpp
+++ b/apps/ktorrent/ktorrent.cpp
@@ -791,14 +791,14 @@ void KTorrent::updatedStats()
//m_statusInfo->setText(i18n("Some info here e.g. connected/disconnected"));
TQString tmp = i18n("Speed down: %1 / up: %2")
- .tqarg(KBytesPerSecToString((double)stats.download_speed/1024.0))
- .tqarg(KBytesPerSecToString((double)stats.upload_speed/1024.0));
+ .arg(KBytesPerSecToString((double)stats.download_speed/1024.0))
+ .arg(KBytesPerSecToString((double)stats.upload_speed/1024.0));
m_statusSpeed->setText(tmp);
TQString tmp1 = i18n("Transferred down: %1 / up: %2")
- .tqarg(BytesToString(stats.bytes_downloaded))
- .tqarg(BytesToString(stats.bytes_uploaded));
+ .arg(BytesToString(stats.bytes_downloaded))
+ .arg(BytesToString(stats.bytes_uploaded));
m_statusTransfer->setText(tmp1);
if (ServerAuthenticate::isFirewalled() && m_core->getNumTorrentsRunning() > 0)
@@ -817,7 +817,7 @@ void KTorrent::updatedStats()
{
const dht::Stats & s = Globals::instance().getDHT().getStats();
m_statusDHT->setText(i18n("DHT: %1 nodes, %2 tasks")
- .tqarg(s.num_peers).tqarg(s.num_tasks));
+ .arg(s.num_peers).arg(s.num_tasks));
}
else
m_statusDHT->setText(i18n("DHT: off"));
diff --git a/apps/ktorrent/ktorrentcore.cpp b/apps/ktorrent/ktorrentcore.cpp
index e97dc84..de0984a 100644
--- a/apps/ktorrent/ktorrentcore.cpp
+++ b/apps/ktorrent/ktorrentcore.cpp
@@ -114,7 +114,7 @@ KTorrentCore::KTorrentCore(kt::GUIInterface* gui) : max_downloads(0),keep_seedin
KMessageBox::information(0,
i18n("Specified port (%1) is unavailable or in"
" use by another application. KTorrent is now using port %2.")
- .tqarg(port).tqarg(port + i - 1));
+ .arg(port).arg(port + i - 1));
Out(SYS_GEN|LOG_NOTICE) << "Bound to port " << (port + i - 1) << endl;
}
@@ -122,7 +122,7 @@ KTorrentCore::KTorrentCore(kt::GUIInterface* gui) : max_downloads(0),keep_seedin
{
KMessageBox::error(0,
i18n("KTorrent is unable to accept connections because the ports %1 to %2 are "
- "already in use by another program.").tqarg(port).tqarg(port + i - 1));
+ "already in use by another program.").arg(port).arg(port + i - 1));
Out(SYS_GEN|LOG_IMPORTANT) << "Cannot find free port" << endl;
}
@@ -465,7 +465,7 @@ TQString KTorrentCore::findNewTorrentDir() const
while (true)
{
TQDir d;
- TQString dir = data_dir + TQString("tor%1/").tqarg(i);
+ TQString dir = data_dir + TQString("tor%1/").arg(i);
if (!d.exists(dir))
{
return dir;
@@ -764,7 +764,7 @@ void KTorrentCore::makeTorrent(const TQString & file,const TQStringList & tracke
// Show error message
KMessageBox::error(0,
- i18n("Cannot create torrent: %1").tqarg(e.toString()),
+ i18n("Cannot create torrent: %1").arg(e.toString()),
i18n("Error"));
}
}
@@ -889,7 +889,7 @@ void KTorrentCore::queue(kt::TorrentInterface* tc)
TorrentInterface* KTorrentCore::getTorFromNumber(int tornumber)
{
- TQString tordir = data_dir + "tor" + TQString("%1").tqarg(tornumber) + "/";
+ TQString tordir = data_dir + "tor" + TQString("%1").arg(tornumber) + "/";
Out() << "tordir " << tordir << endl;
TQPtrList<TorrentInterface>::iterator i = qman->begin();
while(i != qman->end())
@@ -1025,7 +1025,7 @@ void KTorrentCore::aboutToBeStarted(kt::TorrentInterface* tc,bool & ret)
if (tc->getStats().multi_file_torrent)
{
- TQString msg = i18n("Several data files of the torrent \"%1\" are missing, do you want to recreate them, or do you want to not download them?").tqarg(tc->getStats().torrent_name);
+ TQString msg = i18n("Several data files of the torrent \"%1\" are missing, do you want to recreate them, or do you want to not download them?").arg(tc->getStats().torrent_name);
int ret = KMessageBox::warningYesNoCancelList(0,msg,missing,TQString(),
KGuiItem(i18n("Recreate")),KGuiItem(i18n("Do Not Download")));
@@ -1038,7 +1038,7 @@ void KTorrentCore::aboutToBeStarted(kt::TorrentInterface* tc,bool & ret)
}
catch (bt::Error & e)
{
- KMessageBox::error(0,i18n("Cannot recreate missing files: %1").tqarg(e.toString()));
+ KMessageBox::error(0,i18n("Cannot recreate missing files: %1").arg(e.toString()));
tc->handleError(i18n("Data files are missing"));
ret = false;
}
@@ -1052,7 +1052,7 @@ void KTorrentCore::aboutToBeStarted(kt::TorrentInterface* tc,bool & ret)
}
catch (bt::Error & e)
{
- KMessageBox::error(0,i18n("Cannot deselect missing files: %1").tqarg(e.toString()));
+ KMessageBox::error(0,i18n("Cannot deselect missing files: %1").arg(e.toString()));
tc->handleError(i18n("Data files are missing"));
ret = false;
}
@@ -1065,7 +1065,7 @@ void KTorrentCore::aboutToBeStarted(kt::TorrentInterface* tc,bool & ret)
}
else
{
- TQString msg = i18n("The file where the data is saved of the torrent \"%1\" is missing, do you want to recreate it?").tqarg(tc->getStats().torrent_name);
+ TQString msg = i18n("The file where the data is saved of the torrent \"%1\" is missing, do you want to recreate it?").arg(tc->getStats().torrent_name);
int ret = KMessageBox::warningYesNo(0,msg, i18n("Recreate"),KGuiItem(i18n("Recreate")),KGuiItem(i18n("Do Not Recreate")));
if (ret == KMessageBox::Yes)
{
@@ -1075,7 +1075,7 @@ void KTorrentCore::aboutToBeStarted(kt::TorrentInterface* tc,bool & ret)
}
catch (bt::Error & e)
{
- KMessageBox::error(0,i18n("Cannot recreate data file: %1").tqarg(e.toString()));
+ KMessageBox::error(0,i18n("Cannot recreate data file: %1").arg(e.toString()));
tc->handleError(i18n("Data file is missing"));
ret = false;
}
diff --git a/apps/ktorrent/ktorrentview.cpp b/apps/ktorrent/ktorrentview.cpp
index e445fbb..5c04732 100644
--- a/apps/ktorrent/ktorrentview.cpp
+++ b/apps/ktorrent/ktorrentview.cpp
@@ -198,9 +198,9 @@ void KTorrentView::setCurrentGroup(Group* group)
}
if (current_group)
- setCaption(TQString("%1 %2/%3").tqarg(current_group->groupName()).tqarg(running).tqarg(total));
+ setCaption(TQString("%1 %2/%3").arg(current_group->groupName()).arg(running).arg(total));
else
- setCaption(i18n("All Torrents %1/%2").tqarg(running).tqarg(total));
+ setCaption(i18n("All Torrents %1/%2").arg(running).arg(total));
onSelectionChanged();
onExecuted(view->currentItem());
@@ -208,7 +208,7 @@ void KTorrentView::setCurrentGroup(Group* group)
void KTorrentView::saveSettings(KConfig* cfg,int idx)
{
- TQString group = TQString("KTorrentView-%1").tqarg(idx);
+ TQString group = TQString("KTorrentView-%1").arg(idx);
view->saveLayout(cfg,group);
cfg->setGroup(group);
filter_bar->saveSettings(cfg);
@@ -217,7 +217,7 @@ void KTorrentView::saveSettings(KConfig* cfg,int idx)
void KTorrentView::loadSettings(KConfig* cfg,int idx)
{
- TQString group = TQString("KTorrentView-%1").tqarg(idx);
+ TQString group = TQString("KTorrentView-%1").arg(idx);
view->restoreLayout(cfg,group);
view->setDragEnabled(true);
@@ -373,7 +373,7 @@ void KTorrentView::removeDownloads()
if (!s.completed)
{
TQString msg = i18n("The torrent %1 has not finished downloading, "
- "do you want to delete the incomplete data, too?").tqarg(s.torrent_name);
+ "do you want to delete the incomplete data, too?").arg(s.torrent_name);
int ret = KMessageBox::questionYesNoCancel(
this,msg,i18n("Remove Download"),
i18n("Delete Data"),i18n("Keep Data"));
@@ -546,9 +546,9 @@ void KTorrentView::update()
total = t;
if (current_group)
- setCaption(TQString("%1 %2/%3").tqarg(current_group->groupName()).tqarg(running).tqarg(total));
+ setCaption(TQString("%1 %2/%3").arg(current_group->groupName()).arg(running).arg(total));
else
- setCaption(i18n("All Torrents %1/%2").tqarg(running).tqarg(total));
+ setCaption(i18n("All Torrents %1/%2").arg(running).arg(total));
onSelectionChanged();
}
@@ -628,7 +628,7 @@ void KTorrentView::checkDataIntegrity()
}
else
{
- KMessageBox::error(0,i18n("You are already checking the data of the torrent %1 !").tqarg(tc->getStats().torrent_name));
+ KMessageBox::error(0,i18n("You are already checking the data of the torrent %1 !").arg(tc->getStats().torrent_name));
}
}
@@ -748,7 +748,7 @@ void KTorrentView::setDownloadLocationSlot()
if (tc)
{
TQString dn;
- dn = KFileDialog::getExistingDirectory(tc->getStats().output_path, this, i18n("Choose download location for %1").tqarg(tc->getStats().torrent_name));
+ dn = KFileDialog::getExistingDirectory(tc->getStats().output_path, this, i18n("Choose download location for %1").arg(tc->getStats().torrent_name));
if(dn.isNull() || dn.isEmpty())
continue;
@@ -872,9 +872,9 @@ void KTorrentView::updateCaption()
total = t;
if (current_group)
- setCaption(TQString("%1 %2/%3").tqarg(current_group->groupName()).tqarg(running).tqarg(total));
+ setCaption(TQString("%1 %2/%3").arg(current_group->groupName()).arg(running).arg(total));
else
- setCaption(i18n("All Torrents %1/%2").tqarg(running).tqarg(total));
+ setCaption(i18n("All Torrents %1/%2").arg(running).arg(total));
}
}
diff --git a/apps/ktorrent/ktorrentviewitem.cpp b/apps/ktorrent/ktorrentviewitem.cpp
index 048692b..a9392bd 100644
--- a/apps/ktorrent/ktorrentviewitem.cpp
+++ b/apps/ktorrent/ktorrentviewitem.cpp
@@ -222,7 +222,7 @@ void KTorrentViewItem::update()
Uint32 secs = tc->getETA();
if(secs == -1)
{
- setText(7,TQString("%1").tqarg(TQChar(0x221E)));
+ setText(7,TQString("%1").arg(TQChar(0x221E)));
eta = -2;
}
else
@@ -233,7 +233,7 @@ void KTorrentViewItem::update()
}
else
{
- setText(7,TQString("%1").tqarg(TQChar(0x221E)));
+ setText(7,TQString("%1").arg(TQChar(0x221E)));
eta = -2;
}
}
@@ -242,23 +242,23 @@ void KTorrentViewItem::update()
if(m_parent->columnVisible(8))
{
- setText(8,TQString("%1 (%2)").tqarg(TQString::number(s.seeders_connected_to)).tqarg(TQString::number(s.seeders_total)));
+ setText(8,TQString("%1 (%2)").arg(TQString::number(s.seeders_connected_to)).arg(TQString::number(s.seeders_total)));
}
if(m_parent->columnVisible(9))
{
- setText(9,TQString("%1 (%2)").tqarg(TQString::number(s.leechers_connected_to)).tqarg(TQString::number(s.leechers_total)));
+ setText(9,TQString("%1 (%2)").arg(TQString::number(s.leechers_connected_to)).arg(TQString::number(s.leechers_total)));
}
if(m_parent->columnVisible(10))
{
- setText(10,i18n("%1 %").tqarg(KGlobal::locale()->formatNumber(Percentage(s),2)));
+ setText(10,i18n("%1 %").arg(KGlobal::locale()->formatNumber(Percentage(s),2)));
}
if(m_parent->columnVisible(11))
{
float ratio = kt::ShareRatio(s);
- setText(11,TQString("%1").tqarg(KGlobal::locale()->formatNumber(ratio,2)));
+ setText(11,TQString("%1").arg(KGlobal::locale()->formatNumber(ratio,2)));
}
if (m_parent->columnVisible(12))
diff --git a/apps/ktorrent/leaktrace.cpp b/apps/ktorrent/leaktrace.cpp
index f3bdb5f..76439ce 100644
--- a/apps/ktorrent/leaktrace.cpp
+++ b/apps/ktorrent/leaktrace.cpp
@@ -180,7 +180,7 @@ static void DeregisterAlloc(void* ptr)
if (!p->left && !p->right)
{
- // no tqchildren so just free p
+ // no children so just free p
if (prev->left == p)
{
free(prev->left);
@@ -214,7 +214,7 @@ static void DeregisterAlloc(void* ptr)
}
else
{
- // both tqchildren exist
+ // both children exist
if (prev->left == p)
{
// attach the left child of p
diff --git a/apps/ktorrent/main.cpp b/apps/ktorrent/main.cpp
index 5e9fcb2..fa21922 100644
--- a/apps/ktorrent/main.cpp
+++ b/apps/ktorrent/main.cpp
@@ -79,7 +79,7 @@ static const char description[] =
bool GrabPIDLock()
{
// create a lock file in /tmp/ with the user id of the current user included in the name
- TQString pid_file = TQString("/tmp/.ktorrent_%1.lock").tqarg(getuid());
+ TQString pid_file = TQString("/tmp/.ktorrent_%1.lock").arg(getuid());
int fd = open(TQFile::encodeName(pid_file),O_RDWR|O_CREAT,0640);
if (fd < 0)
diff --git a/apps/ktorrent/newui/button.cpp b/apps/ktorrent/newui/button.cpp
index 33bdf7f..4819657 100644
--- a/apps/ktorrent/newui/button.cpp
+++ b/apps/ktorrent/newui/button.cpp
@@ -62,9 +62,9 @@ Button::Button(ButtonBar *parent, const TQString text, const TQIconSet &icon,
KConfig *config = kapp->config();
config->setGroup("UI");
- TQString accel = config->readEntry(TQString("button_%1").tqarg(text), "");
+ TQString accel = config->readEntry(TQString("button_%1").arg(text), "");
if (!accel.isEmpty())
- setRealText(TQString("&%1 %2").tqarg(accel).tqarg(m_realText));
+ setRealText(TQString("&%1 %2").arg(accel).arg(m_realText));
}
Button::~Button()
@@ -80,11 +80,11 @@ Button::~Button()
TQString text = m_realText;
if (text.contains(r2))
text.remove(r2);
- config->writeEntry(TQString("button_%1").tqarg(text), r.cap(1));
+ config->writeEntry(TQString("button_%1").arg(text), r.cap(1));
}
else
{
- config->writeEntry(TQString("button_%1").tqarg(m_realText), "");
+ config->writeEntry(TQString("button_%1").arg(m_realText), "");
}
}
@@ -320,7 +320,7 @@ void Button::assignAccel()
if (ok)
{
TQString text = realTextWithoutAccel();
- text = TQString("&%1 %2").tqarg(num).tqarg(text);
+ text = TQString("&%1 %2").arg(num).arg(text);
setRealText(text);
}
}
diff --git a/apps/ktorrent/newui/ddockwindow.cpp b/apps/ktorrent/newui/ddockwindow.cpp
index 3b67ff3..114927a 100644
--- a/apps/ktorrent/newui/ddockwindow.cpp
+++ b/apps/ktorrent/newui/ddockwindow.cpp
@@ -104,7 +104,7 @@ void DDockWindow::setVisible(bool v)
{
//write dock width to the config file
KConfig *config = kapp->config();
- TQString group = TQString("%1").tqarg(m_name);
+ TQString group = TQString("%1").arg(m_name);
config->setGroup(group);
if (m_visible)
@@ -115,7 +115,7 @@ void DDockWindow::setVisible(bool v)
v ? m_widgetStack->show() : m_widgetStack->hide();
m_visible = v;
- m_internalLayout->tqinvalidate();
+ m_internalLayout->invalidate();
if (!m_visible)
{
if (m_position == DDockWindow::Bottom)
@@ -148,7 +148,7 @@ void DDockWindow::loadSettings()
void DDockWindow::saveSettings()
{
KConfig *config = kapp->config();
- TQString group = TQString("%1").tqarg(m_name);
+ TQString group = TQString("%1").arg(m_name);
int invisibleWidth = 0;
config->setGroup(group);
if (config->hasKey("ViewWidth"))
@@ -200,7 +200,7 @@ void DDockWindow::addWidget(const TQString &title, TQWidget *widget, bool skipAc
//if the widget was selected last time the dock is deleted
//we need to show it
KConfig *config = kapp->config();
- TQString group = TQString("%1").tqarg(m_name);
+ TQString group = TQString("%1").arg(m_name);
config->setGroup(group);
if (config->readEntry("ViewLastWidget") == title)
{
diff --git a/apps/ktorrent/newui/dmainwindow.cpp b/apps/ktorrent/newui/dmainwindow.cpp
index a21fa5c..d5edb2f 100644
--- a/apps/ktorrent/newui/dmainwindow.cpp
+++ b/apps/ktorrent/newui/dmainwindow.cpp
@@ -190,7 +190,7 @@ DTabWidget *DMainWindow::splitVertical()
void DMainWindow::invalidateActiveTabWidget()
{
/* TQWidget *focused = m_central->focusWidget();
- kdDebug(9000) << "tqinvalidate: " << focused << endl;
+ kdDebug(9000) << "invalidate: " << focused << endl;
if (focused == 0)
return;
if (!m_widgets.contains(focused))
diff --git a/apps/ktorrent/newui/dtabwidget.cpp b/apps/ktorrent/newui/dtabwidget.cpp
index fd7fad0..202396a 100644
--- a/apps/ktorrent/newui/dtabwidget.cpp
+++ b/apps/ktorrent/newui/dtabwidget.cpp
@@ -90,7 +90,7 @@ void DTabWidget::insertTab(TQWidget *child, const TQString &label, int index)
if (m_closeButton && m_closeButtonShown)
m_closeButton->show();
KTabWidget::insertTab(child, label, index);
- if (index != -1) tabBar()->tqrepaint();
+ if (index != -1) tabBar()->repaint();
}
void DTabWidget::insertTab(TQWidget *child, const TQIconSet &iconset,
@@ -99,7 +99,7 @@ void DTabWidget::insertTab(TQWidget *child, const TQIconSet &iconset,
if (m_closeButton && m_closeButtonShown)
m_closeButton->show();
KTabWidget::insertTab(child, iconset, label, index);
- if (index != -1) tabBar()->tqrepaint();
+ if (index != -1) tabBar()->repaint();
}
/*void DTabWidget::updateHistory(TQWidget *w)
diff --git a/apps/ktorrent/pref.cpp b/apps/ktorrent/pref.cpp
index 4fbc0fd..826663a 100644
--- a/apps/ktorrent/pref.cpp
+++ b/apps/ktorrent/pref.cpp
@@ -281,7 +281,7 @@ bool GeneralPrefPage::apply()
{
TQString err = KResolver::errorString(res.error());
TQString msg = i18n("Cannot lookup %1: %2\n"
- "Please provide a valid IP address or hostname.").tqarg(externalIP).tqarg(err);
+ "Please provide a valid IP address or hostname.").arg(externalIP).arg(err);
KMessageBox::error(0, msg, i18n("Error"));
return false;
}
diff --git a/apps/ktorrent/queuedialog.cpp b/apps/ktorrent/queuedialog.cpp
index 80c6440..d5cb5e5 100644
--- a/apps/ktorrent/queuedialog.cpp
+++ b/apps/ktorrent/queuedialog.cpp
@@ -300,7 +300,7 @@ void QueueDialog::downloadList_currentChanged(TQListViewItem* item)
dlStatus->setText(tc->statusToString());
dlTracker->setText(tc->getTrackersList()->getTrackerURL().prettyURL());
- dlRatio->setText(TQString("%1").tqarg((float)s.bytes_uploaded / s.bytes_downloaded,0,'f',2));
+ dlRatio->setText(TQString("%1").arg((float)s.bytes_uploaded / s.bytes_downloaded,0,'f',2));
dlBytes->setText(BytesToString(s.bytes_left_to_download));
dlDHT->setText(s.priv_torrent ? i18n("No (private torrent)") : i18n("Yes"));
}
@@ -321,7 +321,7 @@ void QueueDialog::seedList_currentChanged(TQListViewItem* item)
ulStatus->setText(tc->statusToString());
ulTracker->setText(tc->getTrackersList()->getTrackerURL().prettyURL());
- ulRatio->setText(TQString("%1").tqarg((float)s.bytes_uploaded / s.bytes_downloaded,0,'f',2));
+ ulRatio->setText(TQString("%1").arg((float)s.bytes_uploaded / s.bytes_downloaded,0,'f',2));
ulBytes->setText(BytesToString(s.bytes_uploaded));
ulDHT->setText(s.priv_torrent ? i18n("No (private torrent)") : i18n("Yes"));
}
diff --git a/apps/ktorrent/scandialog.cpp b/apps/ktorrent/scandialog.cpp
index 292c1ea..80fd681 100644
--- a/apps/ktorrent/scandialog.cpp
+++ b/apps/ktorrent/scandialog.cpp
@@ -67,14 +67,14 @@ void ScanDialog::scan()
}
catch (bt::Error & err)
{
- KMessageBox::error(0,i18n("Error scanning data: %1").tqarg(err.toString()));
+ KMessageBox::error(0,i18n("Error scanning data: %1").arg(err.toString()));
}
}
void ScanDialog::execute(kt::TorrentInterface* tc,bool silently)
{
- m_torrent_label->setText(i18n("Scanning data of <b>%1</b> :").tqarg(tc->getStats().torrent_name));
+ m_torrent_label->setText(i18n("Scanning data of <b>%1</b> :").arg(tc->getStats().torrent_name));
adjustSize();
m_cancel->setEnabled(true);
this->silently = silently;
diff --git a/apps/ktorrent/scandlgbase.ui b/apps/ktorrent/scandlgbase.ui
index 2538680..189e551 100644
--- a/apps/ktorrent/scandlgbase.ui
+++ b/apps/ktorrent/scandlgbase.ui
@@ -96,7 +96,7 @@
<property name="text">
<string>0</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignVCenter|AlignRight</set>
</property>
</widget>
@@ -119,7 +119,7 @@
<property name="text">
<string>0</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignVCenter|AlignRight</set>
</property>
</widget>
diff --git a/apps/ktorrent/speedlimitsdlg.cpp b/apps/ktorrent/speedlimitsdlg.cpp
index 5fbe5b4..69c6a48 100644
--- a/apps/ktorrent/speedlimitsdlg.cpp
+++ b/apps/ktorrent/speedlimitsdlg.cpp
@@ -33,7 +33,7 @@ using namespace kt;
SpeedLimitsDlg::SpeedLimitsDlg(kt::TorrentInterface* ti,TQWidget* parent, const char* name)
: SpeedLimitsDlgBase(parent,name,true,0),tor(ti)
{
- m_main_caption->setText(i18n("Speed limits for <b>%1</b>:").tqarg(tor->getStats().torrent_name));
+ m_main_caption->setText(i18n("Speed limits for <b>%1</b>:").arg(tor->getStats().torrent_name));
Uint32 up,down;
tor->getTrafficLimits(up,down);
m_upload_rate->setValue(up / 1024);
diff --git a/apps/ktorrent/torrentcreatordlg.cpp b/apps/ktorrent/torrentcreatordlg.cpp
index d42c06f..8518de3 100644
--- a/apps/ktorrent/torrentcreatordlg.cpp
+++ b/apps/ktorrent/torrentcreatordlg.cpp
@@ -46,7 +46,7 @@ TorrentCreatorDlg::TorrentCreatorDlg(KTorrentCore* core,TQWidget *parent, const
TQMap<TQString, int> n = bt::Globals::instance().getDHT().getClosestGoodNodes(10);
for(TQMap<TQString, int>::iterator it = n.begin(); it!=n.end(); ++it)
- new TQListViewItem(m_nodeList, it.key(), TQString("%1").tqarg(it.data()));
+ new TQListViewItem(m_nodeList, it.key(), TQString("%1").arg(it.data()));
}
TorrentCreatorDlg::~TorrentCreatorDlg()
@@ -105,7 +105,7 @@ void TorrentCreatorDlg::onCreate()
s += ".torrent";
KProgressDialog* dlg = new KProgressDialog(this,0);
- dlg->setLabel(i18n("Creating %1...").tqarg(s));
+ dlg->setLabel(i18n("Creating %1...").arg(s));
dlg->setModal(true);
dlg->setAllowCancel(false);
dlg->show();
@@ -136,7 +136,7 @@ void TorrentCreatorDlg::btnRemoveNode_clicked()
void TorrentCreatorDlg::btnAddNode_clicked()
{
- new TQListViewItem(m_nodeList, m_node->text(), TQString("%1").tqarg(m_port->value()));
+ new TQListViewItem(m_nodeList, m_node->text(), TQString("%1").arg(m_port->value()));
}
void TorrentCreatorDlg::m_nodeList_selectionChanged(TQListViewItem*)
diff --git a/apps/ktorrent/torrentcreatordlgbase.ui b/apps/ktorrent/torrentcreatordlgbase.ui
index 3db0c49..d051a0e 100644
--- a/apps/ktorrent/torrentcreatordlgbase.ui
+++ b/apps/ktorrent/torrentcreatordlgbase.ui
@@ -436,7 +436,7 @@
<property name="text">
<string>NOTE: Some known good DHT nodes are already inserted. You should probably insert your own IP address and port too if you plan to seed this torrent.</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignVCenter</set>
</property>
</widget>
diff --git a/apps/ktorrent/trayicon.cpp b/apps/ktorrent/trayicon.cpp
index 14a3db7..8588fc2 100644
--- a/apps/ktorrent/trayicon.cpp
+++ b/apps/ktorrent/trayicon.cpp
@@ -88,24 +88,24 @@ void TrayIcon::leaveEvent(TQEvent* )
void TrayIcon::updateStats(const CurrentStats stats, bool showBars,int downloadBandwidth, int uploadBandwidth )
{
TQString tip = i18n("<table cellpadding='2' cellspacing='2' align='center'><tr><td><b>Speed:</b></td><td></td></tr><tr><td>Download: <font color='#1c9a1c'>%1</font></td><td>Upload: <font color='#990000'>%2</font></td></tr><tr><td><b>Transfer:</b></td><td></td></tr><tr><td>Download: <font color='#1c9a1c'>%3</font></td><td>Upload: <font color='#990000'>%4</font></td></tr></table>")
- .tqarg(KBytesPerSecToString((double)stats.download_speed/1024.0))
- .tqarg(KBytesPerSecToString((double)stats.upload_speed/1024.0))
- .tqarg(BytesToString(stats.bytes_downloaded))
- .tqarg(BytesToString(stats.bytes_uploaded));
+ .arg(KBytesPerSecToString((double)stats.download_speed/1024.0))
+ .arg(KBytesPerSecToString((double)stats.upload_speed/1024.0))
+ .arg(BytesToString(stats.bytes_downloaded))
+ .arg(BytesToString(stats.bytes_uploaded));
m_hover_popup->updateText(tip);
if(showBars)
drawSpeedBar(stats.download_speed/1024,stats.upload_speed/1024, downloadBandwidth, uploadBandwidth);
else if (previousDownloadHeight > 0 || previousUploadHeight > 0)
{
- tqrepaint(); // clear the bars if they are disabled
+ repaint(); // clear the bars if they are disabled
previousDownloadHeight = previousUploadHeight = 0;
}
}
void TrayIcon::drawSpeedBar(int downloadSpeed, int uploadSpeed, int downloadBandwidth, int uploadBandwidth )
{
//check if need tqrepaint
if (uploadBandwidth == 0)
uploadBandwidth = 1;
if (downloadBandwidth == 0)
@@ -116,7 +116,7 @@ void TrayIcon::drawSpeedBar(int downloadSpeed, int uploadSpeed, int downloadBand
if(previousDownloadHeight==DownloadHeight && previousUploadHeight==UploadHeight)
return;
- tqrepaint ();
+ repaint ();
TQBrush brushD(green);
TQBrush brushU(red);
@@ -146,9 +146,9 @@ void TrayIcon::finished(TorrentInterface* tc)
TQString msg = i18n("<b>%1</b> has completed downloading."
"<br>Average speed: %2 DL / %3 UL.")
- .tqarg(s.torrent_name)
- .tqarg(KBytesPerSecToString(speed_down / tc->getRunningTimeDL()))
- .tqarg(KBytesPerSecToString(speed_up / tc->getRunningTimeUL()));
+ .arg(s.torrent_name)
+ .arg(KBytesPerSecToString(speed_down / tc->getRunningTimeDL()))
+ .arg(KBytesPerSecToString(speed_up / tc->getRunningTimeUL()));
showPassivePopup(msg,i18n("Download completed"));
}
@@ -164,10 +164,10 @@ void TrayIcon::maxShareRatioReached(kt::TorrentInterface* tc)
TQString msg = i18n("<b>%1</b> has reached its maximum share ratio of %2 and has been stopped."
"<br>Uploaded %3 at an average speed of %4.")
- .tqarg(s.torrent_name)
- .tqarg(loc->formatNumber(s.max_share_ratio,2))
- .tqarg(BytesToString(s.bytes_uploaded))
- .tqarg(KBytesPerSecToString(speed_up / tc->getRunningTimeUL()));
+ .arg(s.torrent_name)
+ .arg(loc->formatNumber(s.max_share_ratio,2))
+ .arg(BytesToString(s.bytes_uploaded))
+ .arg(KBytesPerSecToString(speed_up / tc->getRunningTimeUL()));
showPassivePopup(msg,i18n("Seeding completed"));
}
@@ -183,10 +183,10 @@ void TrayIcon::maxSeedTimeReached(kt::TorrentInterface* tc)
TQString msg = i18n("<b>%1</b> has reached its maximum seed time of %2 hours and has been stopped."
"<br>Uploaded %3 at an average speed of %4.")
- .tqarg(s.torrent_name)
- .tqarg(loc->formatNumber(s.max_seed_time,2))
- .tqarg(BytesToString(s.bytes_uploaded))
- .tqarg(KBytesPerSecToString(speed_up / tc->getRunningTimeUL()));
+ .arg(s.torrent_name)
+ .arg(loc->formatNumber(s.max_seed_time,2))
+ .arg(BytesToString(s.bytes_uploaded))
+ .arg(KBytesPerSecToString(speed_up / tc->getRunningTimeUL()));
showPassivePopup(msg,i18n("Seeding completed"));
}
@@ -198,7 +198,7 @@ void TrayIcon::torrentStoppedByError(kt::TorrentInterface* tc, TQString msg)
const TorrentStats & s = tc->getStats();
TQString err_msg = i18n("<b>%1</b> has been stopped with the following error: <br>%2")
- .tqarg(s.torrent_name).tqarg(msg);
+ .arg(s.torrent_name).arg(msg);
showPassivePopup(err_msg,i18n("Error"));
}
@@ -211,7 +211,7 @@ void TrayIcon::corruptedData(kt::TorrentInterface* tc)
const TorrentStats & s = tc->getStats();
TQString err_msg = i18n("Corrupted data has been found in the torrent <b>%1</b>"
"<br>It would be a good idea to do a data integrity check on the torrent.")
- .tqarg(s.torrent_name);
+ .arg(s.torrent_name);
showPassivePopup(err_msg,i18n("Error"));
}
@@ -227,10 +227,10 @@ void TrayIcon::queuingNotPossible(kt::TorrentInterface* tc)
if (tc->overMaxRatio())
msg = i18n("<b>%1</b> has reached its maximum share ratio of %2 and cannot be enqueued. Remove the limit manually if you want to continue seeding.")
- .tqarg(s.torrent_name).tqarg(loc->formatNumber(s.max_share_ratio,2));
+ .arg(s.torrent_name).arg(loc->formatNumber(s.max_share_ratio,2));
else
msg = i18n("<b>%1</b> has reached its maximum seed time of %2 hours and cannot be enqueued. Remove the limit manually if you want to continue seeding.")
- .tqarg(s.torrent_name).tqarg(loc->formatNumber(s.max_seed_time,2));
+ .arg(s.torrent_name).arg(loc->formatNumber(s.max_seed_time,2));
showPassivePopup(msg,i18n("Torrent cannot be enqueued."));
}
@@ -240,7 +240,7 @@ void TrayIcon::canNotStart(kt::TorrentInterface* tc,kt::TorrentStartResponse rea
if (!Settings::showPopups())
return;
- TQString msg = i18n("Cannot start <b>%1</b> : <br>").tqarg(tc->getStats().torrent_name);
+ TQString msg = i18n("Cannot start <b>%1</b> : <br>").arg(tc->getStats().torrent_name);
switch (reason)
{
case kt::TQM_LIMITS_REACHED:
@@ -274,7 +274,7 @@ void TrayIcon::lowDiskSpace(kt::TorrentInterface * tc, bool stopped)
const TorrentStats & s = tc->getStats();
- TQString msg = i18n("Your disk is running out of space.<br /><b>%1</b> is being downloaded to '%2'.").tqarg(s.torrent_name).tqarg(tc->getDataDir());
+ TQString msg = i18n("Your disk is running out of space.<br /><b>%1</b> is being downloaded to '%2'.").arg(s.torrent_name).arg(tc->getDataDir());
if(stopped)
msg.prepend(i18n("Torrent has been stopped.<br />"));
@@ -335,10 +335,10 @@ void SetMaxRate::makeMenu()
{
if(rate == valuePair[j] && j==0)
{
- setItemChecked(insertItem(TQString("%1").tqarg(valuePair[j]),-1, (j == 0) ? 2 : count()), true);
+ setItemChecked(insertItem(TQString("%1").arg(valuePair[j]),-1, (j == 0) ? 2 : count()), true);
}
else
- insertItem(TQString("%1").tqarg(valuePair[j]),-1, (j == 0) ? 2 : count());
+ insertItem(TQString("%1").arg(valuePair[j]),-1, (j == 0) ? 2 : count());
}
}
@@ -88,24 +88,24 @@ void TrayIcon::leaveEvent(TQEvent* )
void TrayIcon::drawSpeedBar(int downloadSpeed, int uploadSpeed, int downloadBandwidth, int uploadBandwidth )
{
- //check if need tqrepaint
+ //check if need repaint
if (uploadBandwidth == 0)
uploadBandwidth = 1;